<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AuthenticationWidget</name>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="15"/>
        <source>Username:</source>
        <translation>用户名：</translation>
    </message>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="16"/>
        <source>Password:</source>
        <translation>密码：</translation>
    </message>
</context>
<context>
    <name>CadenceGraph</name>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="11"/>
        <source>rpm</source>
        <translation>r/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="12"/>
        <location filename="../src/GUI/cadencegraph.h" line="16"/>
        <source>Cadence</source>
        <translation>踏频</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>平均</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="30"/>
        <source>Max</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="33"/>
        <source>Average</source>
        <translation>平均</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>最大</translation>
    </message>
</context>
<context>
    <name>CadenceGraphItem</name>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="17"/>
        <source>Maximum</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="18"/>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="20"/>
        <source>rpm</source>
        <translation>r/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="19"/>
        <source>Average</source>
        <translation>平均</translation>
    </message>
</context>
<context>
    <name>Data</name>
    <message>
        <location filename="../src/data/data.cpp" line="160"/>
        <source>Supported files</source>
        <translation>支持的文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="161"/>
        <source>CSV files</source>
        <translation>CSV 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="162"/>
        <source>CUP files</source>
        <translation>CUP 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="163"/>
        <source>FIT files</source>
        <translation>FIT 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="164"/>
        <source>GeoJSON files</source>
        <translation>GeoJSON 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="165"/>
        <source>GPI files</source>
        <translation>GPI 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="166"/>
        <source>GPX files</source>
        <translation>GPX 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="167"/>
        <source>IGC files</source>
        <translation>IGC 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="168"/>
        <source>ITN files</source>
        <translation>ITN 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="169"/>
        <source>JPEG images</source>
        <translation>JPEG 图片</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="170"/>
        <source>KML files</source>
        <translation>KML 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="171"/>
        <source>LOC files</source>
        <translation>LOC 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="172"/>
        <source>NMEA files</source>
        <translation>NMEA 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="173"/>
        <source>ONmove files</source>
        <translation>ONmove 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="174"/>
        <source>OV2 files</source>
        <translation>OV2 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="175"/>
        <source>OziExplorer files</source>
        <translation>OziExplorer 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="176"/>
        <source>SLF files</source>
        <translation>SLF 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="177"/>
        <source>SML files</source>
        <translation>SML 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="178"/>
        <source>TCX files</source>
        <translation>TCX 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="179"/>
        <source>TwoNav files</source>
        <translation>TwoNav 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="180"/>
        <source>GPSDump files</source>
        <translation>GPSDump 文件</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="181"/>
        <source>All files</source>
        <translation>所有文件</translation>
    </message>
</context>
<context>
    <name>DirSelectWidget</name>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="18"/>
        <source>System default</source>
        <translation>系统默认</translation>
    </message>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="40"/>
        <source>Select directory</source>
        <translation>选择目录</translation>
    </message>
</context>
<context>
    <name>ElevationGraph</name>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="39"/>
        <location filename="../src/GUI/elevationgraph.h" line="16"/>
        <source>Elevation</source>
        <translation>海拔</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="59"/>
        <source>Up</source>
        <extracomment>Use an Unicode arrow (U+2197) when there is no abbreviation or extremly short term for &quot;Up&quot; in your language</extracomment>
        <translation>上</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="63"/>
        <source>Down</source>
        <extracomment>Use an Unicode arrow (U+2198) when there is no abbreviation or extremly short term for &quot;Down&quot; in your language</extracomment>
        <translation>下</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="66"/>
        <source>Max</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="69"/>
        <source>Min</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>最小</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="72"/>
        <source>Ascent</source>
        <translation>上升</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="74"/>
        <source>Descent</source>
        <translation>下降</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="76"/>
        <source>Maximum</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="78"/>
        <source>Minimum</source>
        <translation>最小</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="181"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="184"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
</context>
<context>
    <name>ElevationGraphItem</name>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="33"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="33"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="36"/>
        <source>Ascent</source>
        <translation>上升</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="38"/>
        <source>Descent</source>
        <translation>下降</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="40"/>
        <source>Maximum</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="42"/>
        <source>Minimum</source>
        <translation>最小</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="46"/>
        <location filename="../src/GUI/fileselectwidget.cpp" line="51"/>
        <source>Select file</source>
        <translation>选择文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="61"/>
        <source>No output file selected.</source>
        <translation>未选择输出文件。</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="71"/>
        <source>%1 is a directory.</source>
        <translation>%1 是一个目录。</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="75"/>
        <source>%1 is not writable.</source>
        <translation>%1 不可写。</translation>
    </message>
</context>
<context>
    <name>Format</name>
    <message>
        <location filename="../src/GUI/format.cpp" line="54"/>
        <location filename="../src/GUI/format.cpp" line="61"/>
        <location filename="../src/GUI/format.cpp" line="84"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="57"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="64"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="68"/>
        <location filename="../src/GUI/format.cpp" line="81"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="71"/>
        <source>km</source>
        <translation>km</translation>
    </message>
</context>
<context>
    <name>GUI</name>
    <message>
        <location filename="../src/GUI/gui.cpp" line="199"/>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="207"/>
        <location filename="../src/GUI/gui.cpp" line="951"/>
        <location filename="../src/GUI/gui.cpp" line="969"/>
        <source>Paths</source>
        <translation>路径</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="211"/>
        <location filename="../src/GUI/gui.cpp" line="911"/>
        <location filename="../src/GUI/gui.cpp" line="912"/>
        <source>Keyboard controls</source>
        <translation>键盘控制</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="215"/>
        <location filename="../src/GUI/gui.cpp" line="878"/>
        <source>About GPXSee</source>
        <translation>关于 GPXSee</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="221"/>
        <source>Open...</source>
        <translation>打开...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="228"/>
        <source>Open directory...</source>
        <translation>打开目录...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="233"/>
        <source>Print...</source>
        <translation>打印...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="239"/>
        <source>Export to PDF...</source>
        <translation>导出为 PDF...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="246"/>
        <source>Export to PNG...</source>
        <translation>导出为 PNG...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="253"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="260"/>
        <source>Reload</source>
        <translation>重新加载</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="266"/>
        <source>Statistics...</source>
        <translation>统计...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="276"/>
        <source>Clear list</source>
        <translation>清空列表</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="288"/>
        <source>Load POI file...</source>
        <translation>载入 POI 文件...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="292"/>
        <source>Select all files</source>
        <translation>选择所有文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="297"/>
        <source>Unselect all files</source>
        <translation>取消选择所有文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="302"/>
        <source>Overlap POIs</source>
        <translation>叠加 POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="307"/>
        <source>Show POI icons</source>
        <translation>显示 POI 图标</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="312"/>
        <source>Show POI labels</source>
        <translation>显示 POI 标签</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="318"/>
        <source>Show POIs</source>
        <translation>显示 POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="330"/>
        <source>Show map</source>
        <translation>显示地图</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="339"/>
        <source>Load map...</source>
        <translation>载入地图...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="344"/>
        <source>Load map directory...</source>
        <translation>载入地图目录...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="347"/>
        <source>Clear tile cache</source>
        <translation>清除瓦片缓存</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="352"/>
        <location filename="../src/GUI/gui.cpp" line="357"/>
        <location filename="../src/GUI/gui.cpp" line="930"/>
        <source>Next map</source>
        <translation>下一个地图</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="362"/>
        <source>Show cursor coordinates</source>
        <translation>显示光标的坐标</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="370"/>
        <source>Show position</source>
        <translation>显示位置</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="376"/>
        <source>Follow position</source>
        <translation>跟随位置</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="381"/>
        <source>Show coordinates</source>
        <translation>显示坐标</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="387"/>
        <source>Show motion info</source>
        <translation>显示移动信息</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="394"/>
        <source>Show tracks</source>
        <translation>显示航迹</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="399"/>
        <source>Show routes</source>
        <translation>显示航线</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="403"/>
        <source>Show waypoints</source>
        <translation>显示航点</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="408"/>
        <source>Show areas</source>
        <translation>显示区域</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="412"/>
        <source>Waypoint icons</source>
        <translation>航点图标</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="417"/>
        <source>Waypoint labels</source>
        <translation>航点标签</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="422"/>
        <source>Route waypoints</source>
        <translation>航线航点</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="427"/>
        <source>km/mi markers</source>
        <translation>km/mi 标记</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="435"/>
        <source>Do not show</source>
        <translation>不显示</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="439"/>
        <source>Marker only</source>
        <translation>仅标记</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="443"/>
        <source>Date/time</source>
        <translation>日期/时间</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="447"/>
        <source>Coordinates</source>
        <translation>坐标</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="451"/>
        <source>Use styles</source>
        <translation>使用样式</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="458"/>
        <source>Download data DEM</source>
        <translation>下载 DEM 数据</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="464"/>
        <source>Download map DEM</source>
        <translation>下载 DEM 地图</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="469"/>
        <source>Show local DEM tiles</source>
        <translation>显示本地 DEM 瓦片</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="472"/>
        <source>Show hillshading</source>
        <translation>显示山体阴影</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="480"/>
        <source>Show graphs</source>
        <translation>显示图表</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="488"/>
        <location filename="../src/GUI/gui.cpp" line="1370"/>
        <location filename="../src/GUI/gui.cpp" line="1430"/>
        <source>Distance</source>
        <translation>距离</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="495"/>
        <location filename="../src/GUI/gui.cpp" line="740"/>
        <location filename="../src/GUI/gui.cpp" line="1372"/>
        <location filename="../src/GUI/gui.cpp" line="1432"/>
        <source>Time</source>
        <translation>时间</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="501"/>
        <source>Show grid</source>
        <translation>显示网格</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="506"/>
        <source>Show slider info</source>
        <translation>显示滑块信息</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="512"/>
        <source>Show tabs</source>
        <translation>显示选项卡</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="521"/>
        <source>Show toolbars</source>
        <translation>显示工具栏</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="528"/>
        <source>Total time</source>
        <translation>总时长</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="533"/>
        <location filename="../src/GUI/gui.cpp" line="1373"/>
        <location filename="../src/GUI/gui.cpp" line="1434"/>
        <source>Moving time</source>
        <translation>移动时长</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="540"/>
        <source>Metric</source>
        <translation>公制</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="545"/>
        <source>Imperial</source>
        <translation>英制</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="551"/>
        <source>Nautical</source>
        <translation>航海</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="559"/>
        <source>Decimal degrees (DD)</source>
        <translation>小数度数 (DD)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="565"/>
        <source>Degrees and decimal minutes (DMM)</source>
        <translation>度、十进制分 (DMM)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="572"/>
        <source>Degrees, minutes, seconds (DMS)</source>
        <translation>度、分、秒 (DMS)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="579"/>
        <source>Fullscreen mode</source>
        <translation>全屏模式</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="586"/>
        <source>Options...</source>
        <translation>选项...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="593"/>
        <source>Next</source>
        <translation>下一个</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="598"/>
        <source>Previous</source>
        <translation>上一个</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="603"/>
        <source>Last</source>
        <translation>最后一个</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="608"/>
        <source>First</source>
        <translation>第一个</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="643"/>
        <source>&amp;File</source>
        <translation>文件(&amp;F)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="646"/>
        <source>Open recent</source>
        <translation>最近打开文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="671"/>
        <source>&amp;Map</source>
        <translation>地图(&amp;M)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="681"/>
        <source>&amp;Graph</source>
        <translation>图表(&amp;G)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="693"/>
        <source>&amp;Data</source>
        <translation>数据(&amp;D)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="698"/>
        <source>Position info</source>
        <translation>位置信息</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="712"/>
        <source>&amp;POI</source>
        <translation>POI(&amp;P)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="724"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="732"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="739"/>
        <source>&amp;Settings</source>
        <translation>设置(&amp;S)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="744"/>
        <source>Units</source>
        <translation>单位</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="749"/>
        <source>Coordinates format</source>
        <translation>坐标格式</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="762"/>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="789"/>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="799"/>
        <source>Show</source>
        <translation>显示</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="807"/>
        <source>Navigation</source>
        <translation>导航</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="880"/>
        <location filename="../src/GUI/gui.cpp" line="888"/>
        <source>Version %1</source>
        <translation>版本 %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="883"/>
        <location filename="../src/GUI/gui.cpp" line="892"/>
        <source>GPXSee is distributed under the terms of the GNU General Public License version 3. For more info about GPXSee visit the project homepage at %1.</source>
        <translation>GPXSee 依照《GNU 通用公共许可证 v3.0》之条款发布。有关 GPXSee 的详细信息，请访问项目主页 %1 。</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="915"/>
        <source>Next file</source>
        <translation>下一个文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="916"/>
        <source>Previous file</source>
        <translation>上一个文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="918"/>
        <source>First file</source>
        <translation>第一个文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="920"/>
        <source>Last file</source>
        <translation>最后一个文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="921"/>
        <source>Append file</source>
        <translation>追加文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="922"/>
        <source>Next/Previous</source>
        <translation>下一个/上一个</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="924"/>
        <source>Toggle graph type</source>
        <translation>切换图表类型</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="926"/>
        <source>Toggle time type</source>
        <translation>切换时间类型</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="928"/>
        <source>Toggle position info</source>
        <translation>切换位置信息</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="932"/>
        <source>Previous map</source>
        <translation>上一个地图</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="933"/>
        <source>Zoom in</source>
        <translation>放大</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="935"/>
        <source>Zoom out</source>
        <translation>缩小</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="937"/>
        <source>Digital zoom</source>
        <translation>数字缩放</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="938"/>
        <source>Zoom</source>
        <translation>缩放</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="939"/>
        <source>Copy coordinates</source>
        <translation>复制坐标</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="940"/>
        <source>Left Click</source>
        <translation>左击</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="954"/>
        <location filename="../src/GUI/gui.cpp" line="972"/>
        <source>Map directory:</source>
        <translation>地图目录：</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="956"/>
        <location filename="../src/GUI/gui.cpp" line="974"/>
        <source>POI directory:</source>
        <translation>POI 目录：</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="958"/>
        <location filename="../src/GUI/gui.cpp" line="976"/>
        <source>CRS directory:</source>
        <translation>CRS 目录：</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="960"/>
        <location filename="../src/GUI/gui.cpp" line="978"/>
        <source>DEM directory:</source>
        <translation>DEM 目录：</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="962"/>
        <location filename="../src/GUI/gui.cpp" line="980"/>
        <source>Styles directory:</source>
        <translation>样式目录：</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="964"/>
        <location filename="../src/GUI/gui.cpp" line="982"/>
        <source>Symbols directory:</source>
        <translation>符号目录：</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="966"/>
        <location filename="../src/GUI/gui.cpp" line="984"/>
        <source>Tile cache directory:</source>
        <translation>瓦片缓存目录：</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="995"/>
        <location filename="../src/GUI/gui.cpp" line="998"/>
        <source>Open file</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1030"/>
        <source>Open directory</source>
        <translation>打开目录</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1093"/>
        <source>Error loading data file:</source>
        <translation>加载数据文件出错：</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1096"/>
        <location filename="../src/GUI/gui.cpp" line="1208"/>
        <source>Line: %1</source>
        <translation>行：%1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1101"/>
        <location filename="../src/GUI/gui.cpp" line="1778"/>
        <location filename="../src/GUI/gui.cpp" line="1878"/>
        <source>Don&apos;t show again</source>
        <translation>不要再次显示</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1175"/>
        <location filename="../src/GUI/gui.cpp" line="1178"/>
        <source>Open POI file</source>
        <translation>打开 POI 文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1205"/>
        <source>Error loading POI file:</source>
        <translation>加载POI文件出错：</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1352"/>
        <location filename="../src/GUI/gui.cpp" line="1410"/>
        <source>Tracks</source>
        <translation>航迹</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1354"/>
        <location filename="../src/GUI/gui.cpp" line="1412"/>
        <source>Routes</source>
        <translation>航线</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1356"/>
        <location filename="../src/GUI/gui.cpp" line="1414"/>
        <source>Waypoints</source>
        <translation>航点</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1358"/>
        <location filename="../src/GUI/gui.cpp" line="1416"/>
        <source>Areas</source>
        <translation>区域</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1362"/>
        <location filename="../src/GUI/gui.cpp" line="1364"/>
        <location filename="../src/GUI/gui.cpp" line="1421"/>
        <location filename="../src/GUI/gui.cpp" line="1423"/>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1385"/>
        <location filename="../src/GUI/gui.cpp" line="1388"/>
        <location filename="../src/GUI/gui.cpp" line="1389"/>
        <source>Statistics</source>
        <translation>统计</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1406"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1717"/>
        <location filename="../src/GUI/gui.cpp" line="1720"/>
        <source>Open map file</source>
        <translation>打开地图文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1772"/>
        <location filename="../src/GUI/gui.cpp" line="1829"/>
        <location filename="../src/GUI/gui.cpp" line="1848"/>
        <location filename="../src/GUI/gui.cpp" line="1872"/>
        <source>Error loading map:</source>
        <translation>加载地图出错：</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1912"/>
        <source>Select map directory</source>
        <translation>选择地图目录</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1941"/>
        <source>Clear &quot;%1&quot; tile cache?</source>
        <translation>清除&quot;%1 &quot;瓦片缓存？</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1961"/>
        <source>DEM tiles download limit exceeded. If you really need data for such a huge area, download the files manually.</source>
        <translation>已超过 DEM 瓦片下载限额。如您确需大量数据，请手动下载。</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="1964"/>
        <source>Download %n DEM tiles?</source>
        <translation>
            <numerusform>下载 %n DEM 瓦片？</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1977"/>
        <source>Could not download all required DEM files.</source>
        <translation>无法下载所有需要的 DEM 文件。</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1997"/>
        <source>No local DEM tiles found.</source>
        <translation>未找到本地 DEM 瓦片。</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2011"/>
        <source>No files loaded</source>
        <translation>没有加载文件</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2015"/>
        <source>%n files</source>
        <translation>
            <numerusform>%n 文件</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GearRatioGraph</name>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="12"/>
        <location filename="../src/GUI/gearratiograph.h" line="17"/>
        <source>Gear ratio</source>
        <translation>齿比</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="28"/>
        <source>Top</source>
        <translation>顶部</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="30"/>
        <source>Min</source>
        <translation>最小</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="32"/>
        <source>Max</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="35"/>
        <source>Most used</source>
        <translation>最常用的</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>最小</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>最大</translation>
    </message>
</context>
<context>
    <name>GearRatioGraphItem</name>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="35"/>
        <source>Minimum</source>
        <translation>最小</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="36"/>
        <source>Maximum</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="37"/>
        <source>Most used</source>
        <translation>最常用的</translation>
    </message>
</context>
<context>
    <name>GraphView</name>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="74"/>
        <source>Data not available</source>
        <translation>数据不可用</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="94"/>
        <location filename="../src/GUI/graphview.cpp" line="199"/>
        <source>Distance</source>
        <translation>距离</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="131"/>
        <location filename="../src/GUI/graphview.cpp" line="139"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="134"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="142"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="147"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="150"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="156"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="159"/>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="162"/>
        <source>h</source>
        <translation>h</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="201"/>
        <source>Time</source>
        <translation>时间</translation>
    </message>
</context>
<context>
    <name>HeartRateGraph</name>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="11"/>
        <source>bpm</source>
        <translation>b/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="12"/>
        <location filename="../src/GUI/heartrategraph.h" line="16"/>
        <source>Heart rate</source>
        <translation>心率</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>平均</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="30"/>
        <source>Max</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="33"/>
        <source>Average</source>
        <translation>平均</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>最大</translation>
    </message>
</context>
<context>
    <name>HeartRateGraphItem</name>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="17"/>
        <source>Maximum</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="18"/>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="20"/>
        <source>bpm</source>
        <translation>b/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="19"/>
        <source>Average</source>
        <translation>平均</translation>
    </message>
</context>
<context>
    <name>MapItem</name>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="79"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="81"/>
        <source>File</source>
        <translation>文件</translation>
    </message>
</context>
<context>
    <name>MapList</name>
    <message>
        <location filename="../src/map/maplist.cpp" line="158"/>
        <source>Supported files</source>
        <translation>支持的文件</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="162"/>
        <source>AlpineQuest maps</source>
        <translation>AlpineQuest 地图</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="164"/>
        <source>Garmin IMG maps</source>
        <translation>佳明 IMG 地图</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="166"/>
        <source>Garmin JNX maps</source>
        <translation>佳明 JNX 地图</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="167"/>
        <source>BSB nautical charts</source>
        <translation>BSB 海图</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="163"/>
        <source>GEMF maps</source>
        <translation>GEMF 地图</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="160"/>
        <source>Electronic Navigational Charts</source>
        <translation>电子航海图</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="168"/>
        <source>KMZ maps</source>
        <translation>KMZ 地图</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="169"/>
        <source>Mapsforge maps</source>
        <translation>Mapsforge 地图</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="170"/>
        <source>OziExplorer maps</source>
        <translation>OziExplorer 地图</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="171"/>
        <source>MBTiles maps</source>
        <translation>MBTiles 地图</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="172"/>
        <source>Orux maps</source>
        <translation>Orux 地图</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="173"/>
        <source>QuickChart maps</source>
        <translation>QuickChart 地图</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="174"/>
        <source>TwoNav maps</source>
        <translation>TwoNav 地图</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="175"/>
        <source>Osmdroid SQLite maps</source>
        <translation>Osmdroid SQLite 地图</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="176"/>
        <source>Locus/OsmAnd/RMaps SQLite maps</source>
        <translation>Locus/OsmAnd/RMaps SQLite 地图</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="178"/>
        <source>TrekBuddy maps/atlases</source>
        <translation>TrekBuddy 地图/地图集</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="180"/>
        <source>GeoTIFF images</source>
        <translation>GeoTIFF 图像</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="181"/>
        <source>World-file georeferenced images</source>
        <translation>World-file georeferenced 图像</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="183"/>
        <source>Online map sources</source>
        <translation>在线地图源</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="184"/>
        <source>All files</source>
        <translation>所有文件</translation>
    </message>
</context>
<context>
    <name>MotionInfoItem</name>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="87"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="90"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="93"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="100"/>
        <source>ft/min</source>
        <translation>ft/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="103"/>
        <source>m/min</source>
        <translation>m/min</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="70"/>
        <source>Select the proper coordinate reference system (CRS) of maps without a CRS definition (JNX, KMZ and World file maps).</source>
        <translation>为没有CRS定义的地图（JNX、KMZ和世界文件地图）选择适合的坐标参考系（CRS）。</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="73"/>
        <source>Select the desired projection of vector maps (IMG, Mapsforge and ENC maps). The projection must be valid for the whole map area.</source>
        <translation>选择所需的矢量地图投影（IMG、Mapsforge和ENC地图）。该投影必须对整个地图区域有效。</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="78"/>
        <source>Standard</source>
        <translation>标准</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="83"/>
        <source>Non-HiDPI maps are loaded as HiDPI maps. The map is sharp but map objects are small/hard to read.</source>
        <translation>非HiDPI地图将作为HiDPI地图加载。地图显示将较清晰，但其中的对象可能极小以难以阅读。</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="85"/>
        <source>Non-HiDPI maps are loaded such as they are. Map objects have the expected size but the map is blurry.</source>
        <translation>非HiDPI地图将按原样加载。地图对象将以预设大小显示，但地图会模糊。</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="95"/>
        <source>Input</source>
        <translation>输入</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="97"/>
        <source>Output</source>
        <translation>输出</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="104"/>
        <source>Input:</source>
        <translation>输入：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="107"/>
        <source>Output:</source>
        <translation>输出：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="128"/>
        <source>Projection</source>
        <translation>投影</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="129"/>
        <source>HiDPI display mode</source>
        <translation>HiDPI显示模式</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="139"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="146"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="152"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="220"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="227"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="265"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="628"/>
        <source>px</source>
        <translation>像素</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="163"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="267"/>
        <source>Use anti-aliasing</source>
        <translation>启用抗锯齿</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="169"/>
        <source>Track width:</source>
        <translation>航迹宽度：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="170"/>
        <source>Track style:</source>
        <translation>航迹样式：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="172"/>
        <source>Route width:</source>
        <translation>航线宽度：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="173"/>
        <source>Route style:</source>
        <translation>航线样式：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="175"/>
        <source>Area border width:</source>
        <translation>区域边框宽度：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="176"/>
        <source>Area border style:</source>
        <translation>区域边框样式：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="177"/>
        <source>Area fill opacity:</source>
        <translation>区域填充不透明度：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="179"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="202"/>
        <source>Base color:</source>
        <translation>基础颜色：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="180"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="203"/>
        <source>Palette shift:</source>
        <translation>调色板偏移：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="186"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="191"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="196"/>
        <source>Width:</source>
        <translation>宽度：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="187"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="192"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="197"/>
        <source>Style:</source>
        <translation>样式：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="188"/>
        <source>Tracks</source>
        <translation>航迹</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="193"/>
        <source>Routes</source>
        <translation>航线</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="199"/>
        <source>Areas</source>
        <translation>区域</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="235"/>
        <source>Waypoint color:</source>
        <translation>航点颜色：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="236"/>
        <source>Waypoint size:</source>
        <translation>航点大小：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="238"/>
        <source>POI color:</source>
        <translation>POI 颜色：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="239"/>
        <source>POI size:</source>
        <translation>POI 大小：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="243"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="248"/>
        <source>Color:</source>
        <translation>颜色：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="244"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="249"/>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="245"/>
        <source>Waypoints</source>
        <translation>航点</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="250"/>
        <source>POIs</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="273"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="279"/>
        <source>Line width:</source>
        <translation>线条宽度：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="274"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="280"/>
        <source>Slider color:</source>
        <translation>滑块颜色：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="301"/>
        <source>Info background</source>
        <translation>信息背景</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="305"/>
        <source>Background color:</source>
        <translation>背景颜色：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="307"/>
        <source>Crosshair color:</source>
        <translation>十字线颜色：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="308"/>
        <source>Info color:</source>
        <translation>信息颜色：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="318"/>
        <source>Paths</source>
        <translation>线</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="319"/>
        <source>Points</source>
        <translation>点</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="320"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="757"/>
        <source>Graphs</source>
        <translation>图表</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="321"/>
        <source>Map</source>
        <translation>地图</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="328"/>
        <source>Moving average window size</source>
        <translation>移动平均窗口大小</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="346"/>
        <source>Eliminate GPS outliers</source>
        <translation>消除 GPS 异常值</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="352"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="370"/>
        <source>Smoothing</source>
        <translation>平滑</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="353"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="363"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="480"/>
        <source>Elevation:</source>
        <translation>海拔：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="354"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="364"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="479"/>
        <source>Speed:</source>
        <translation>速度：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="355"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="365"/>
        <source>Heart rate:</source>
        <translation>心率：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="356"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="366"/>
        <source>Cadence:</source>
        <translation>踏频：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="357"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="367"/>
        <source>Power:</source>
        <translation>功率：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="380"/>
        <source>Automatic</source>
        <translation>自动</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="381"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="431"/>
        <source>Custom</source>
        <translation>自定义</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="394"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="397"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="400"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="404"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="784"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="411"/>
        <source>Computed from distance/time</source>
        <translation>根据距离/时间计算</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="412"/>
        <source>Recorded by device</source>
        <translation>根据设备记录</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="417"/>
        <source>Show secondary speed</source>
        <translation>显示次要速度</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="420"/>
        <source>GPS data</source>
        <translation>GPS 数据</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="421"/>
        <source>DEM data</source>
        <translation>DEM 数据</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="426"/>
        <source>Show secondary elevation</source>
        <translation>显示次要海拔</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="429"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="430"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="835"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="886"/>
        <source>System</source>
        <translation>系统</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="450"/>
        <source>Use segments</source>
        <translation>启用分段</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="481"/>
        <source>Time zone:</source>
        <translation>时区：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="495"/>
        <source>Speed</source>
        <translation>速度</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="500"/>
        <source>Elevation</source>
        <translation>海拔</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="506"/>
        <source>Time zone</source>
        <translation>时区</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="527"/>
        <source>Minimal speed:</source>
        <translation>最小速度：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="528"/>
        <source>Minimal duration:</source>
        <translation>最短持续时间：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="539"/>
        <source>Sources</source>
        <translation>来源</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="540"/>
        <source>Filtering</source>
        <translation>过滤</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="541"/>
        <source>Pause detection</source>
        <translation>暂停检测</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="553"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="556"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="559"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="563"/>
        <source>Radius:</source>
        <translation>半径：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="569"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="877"/>
        <source>POI</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="586"/>
        <source>Use HTTP authentication</source>
        <translation>启用 HTTP 验证</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="592"/>
        <source>Use $lat and $lon for NYY/SYY and EXXX/WXXX in the URL.</source>
        <translation>在网址中使用$lat和$lon表示NYY/SYY和EXXX/WXXX。</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="597"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="610"/>
        <source>URL:</source>
        <translation>网址：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="198"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="306"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="644"/>
        <source>Opacity:</source>
        <translation>透明度：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="646"/>
        <source>Blur radius:</source>
        <translation>模糊半径：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="648"/>
        <source>Azimuth:</source>
        <translation>方位角：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="649"/>
        <source>Altitude:</source>
        <translation>海拔：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="650"/>
        <source>Z Factor:</source>
        <translation>Z 因子：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="655"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="689"/>
        <source>Source</source>
        <translation>源</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="656"/>
        <source>Hillshading</source>
        <translation>山体阴影</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="676"/>
        <source>Plugin:</source>
        <translation>插件：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="696"/>
        <source>WYSIWYG</source>
        <translation>所见即所得</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="77"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="697"/>
        <source>High-Resolution</source>
        <translation>高分辨率</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="645"/>
        <source>Lightening:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="702"/>
        <source>The printed area is approximately the display area. The map zoom level does not change.</source>
        <translation>打印区域近似于显示区域。地图的缩放级别不会改变。</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="704"/>
        <source>The zoom level will be changed so that the whole content (tracks/waypoints) fits to the printed area and the map resolution is as close as possible to the print resolution.</source>
        <translation>缩放级别将被改变以使整个内容（航迹/航点）适应打印区域，并且地图分辨率尽可能接近打印分辨率。</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="720"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="722"/>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="724"/>
        <source>Distance</source>
        <translation>距离</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="726"/>
        <source>Time</source>
        <translation>时间</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="728"/>
        <source>Moving time</source>
        <translation>移动时长</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="730"/>
        <source>Item count (&gt;1)</source>
        <translation>项目数(&gt;1)</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="745"/>
        <source>Separate graph page</source>
        <translation>单独图表页</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="755"/>
        <source>Print mode</source>
        <translation>打印模式</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="756"/>
        <source>Header</source>
        <translation>页眉</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="764"/>
        <source>Use OpenGL</source>
        <translation>启用 OpenGL</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="766"/>
        <source>Enable HTTP/2</source>
        <translation>启用 HTTP/2</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="772"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="778"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="790"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="798"/>
        <source>Image cache size:</source>
        <translation>图像缓存大小：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="792"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="800"/>
        <source>Connection timeout:</source>
        <translation>连接超时：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="791"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="799"/>
        <source>DEM cache size:</source>
        <translation>DEM 缓存大小：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="819"/>
        <source>Select the initial paths of the file open dialogues. Leave the field empty for the system default.</source>
        <translation>为文件打开对话框设置初始路径。留空则为系统默认。</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="823"/>
        <source>Data:</source>
        <translation>数据：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="824"/>
        <source>Maps:</source>
        <translation>地图：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="825"/>
        <source>POI:</source>
        <translation>POI：</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="836"/>
        <source>Initial paths</source>
        <translation>初始路径</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="872"/>
        <source>Appearance</source>
        <translation>外观</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="874"/>
        <source>Maps</source>
        <translation>地图</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="876"/>
        <source>Data</source>
        <translation>数据</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="879"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="882"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="884"/>
        <source>Print &amp; Export</source>
        <translation>打印 &amp; 导出</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="919"/>
        <source>Options</source>
        <translation>选项</translation>
    </message>
</context>
<context>
    <name>PDFExportDialog</name>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>PDF files</source>
        <translation>PDF 文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>All files</source>
        <translation>所有文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="56"/>
        <source>Portrait</source>
        <translation>纵向</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="57"/>
        <source>Landscape</source>
        <translation>横向</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>cm</source>
        <translation>cm</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>in</source>
        <translation>in</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="73"/>
        <source>Page Setup</source>
        <translation>页面设置</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="76"/>
        <source>Page size:</source>
        <translation>页面大小：</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="77"/>
        <source>Resolution:</source>
        <translation>分辨率：</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="78"/>
        <source>Orientation:</source>
        <translation>方向：</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="79"/>
        <source>Margins:</source>
        <translation>边距：</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="85"/>
        <source>File:</source>
        <translation>文件：</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="92"/>
        <source>Output file</source>
        <translation>输出文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="99"/>
        <source>Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="119"/>
        <source>Export to PDF</source>
        <translation>导出为 PDF</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="127"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
</context>
<context>
    <name>PNGExportDialog</name>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>PNG files</source>
        <translation>PNG 文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>All files</source>
        <translation>所有文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="34"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="39"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="43"/>
        <source>px</source>
        <translation>像素</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="45"/>
        <source>Use anti-aliasing</source>
        <translation>启用抗锯齿</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="49"/>
        <source>Image Setup</source>
        <translation>图像设置</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="52"/>
        <source>Image width:</source>
        <translation>图像宽度：</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="53"/>
        <source>Image height:</source>
        <translation>图像高度：</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="54"/>
        <source>Margins:</source>
        <translation>边距：</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="61"/>
        <source>File:</source>
        <translation>文件：</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="68"/>
        <source>Output file</source>
        <translation>输出文件</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="75"/>
        <source>Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="95"/>
        <source>Export to PNG</source>
        <translation>导出为 PNG</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="103"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
</context>
<context>
    <name>PolygonItem</name>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="17"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="19"/>
        <source>Description</source>
        <translation>描述</translation>
    </message>
</context>
<context>
    <name>PowerGraph</name>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="11"/>
        <source>W</source>
        <translation>瓦</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="12"/>
        <location filename="../src/GUI/powergraph.h" line="16"/>
        <source>Power</source>
        <translation>功率</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>平均</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="30"/>
        <source>Max</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="33"/>
        <source>Average</source>
        <translation>平均</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>最大</translation>
    </message>
</context>
<context>
    <name>PowerGraphItem</name>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="17"/>
        <source>Maximum</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="18"/>
        <location filename="../src/GUI/powergraphitem.cpp" line="20"/>
        <source>W</source>
        <translation>瓦</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="19"/>
        <source>Average</source>
        <translation>平均</translation>
    </message>
</context>
<context>
    <name>RouteItem</name>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="16"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="18"/>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="20"/>
        <source>Comment</source>
        <translation>评论</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="21"/>
        <source>Distance</source>
        <translation>距离</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="32"/>
        <source>Links</source>
        <translation>链接</translation>
    </message>
</context>
<context>
    <name>ScaleItem</name>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="108"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="109"/>
        <location filename="../src/GUI/scaleitem.cpp" line="112"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="111"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="114"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="115"/>
        <source>m</source>
        <translation>m</translation>
    </message>
</context>
<context>
    <name>SpeedGraph</name>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="15"/>
        <location filename="../src/GUI/speedgraph.h" line="18"/>
        <source>Speed</source>
        <translation>速度</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="30"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="34"/>
        <source>Avg</source>
        <translation>平均</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="36"/>
        <source>Max</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="39"/>
        <source>Average</source>
        <translation>平均</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="41"/>
        <source>Maximum</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="44"/>
        <source>Pace</source>
        <translation>配速</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="133"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="136"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="139"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
</context>
<context>
    <name>SpeedGraphItem</name>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="23"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="24"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="24"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="27"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="28"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="28"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="31"/>
        <source>Maximum</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="33"/>
        <source>Average</source>
        <translation>平均</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="35"/>
        <source>Pace</source>
        <translation>配速</translation>
    </message>
</context>
<context>
    <name>TemperatureGraph</name>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="12"/>
        <location filename="../src/GUI/temperaturegraph.h" line="16"/>
        <source>Temperature</source>
        <translation>温度</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>平均</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="30"/>
        <source>Min</source>
        <translation>最小</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="32"/>
        <source>Max</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="35"/>
        <source>Average</source>
        <translation>平均</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>最小</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="111"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="115"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>TemperatureGraphItem</name>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="21"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="21"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="24"/>
        <source>Average</source>
        <translation>平均值</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="26"/>
        <source>Maximum</source>
        <translation>最大</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="28"/>
        <source>Minimum</source>
        <translation>最小</translation>
    </message>
</context>
<context>
    <name>TrackItem</name>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="15"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="17"/>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="19"/>
        <source>Comment</source>
        <translation>评论</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="20"/>
        <source>Distance</source>
        <translation>距离</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="23"/>
        <source>Total time</source>
        <translation>总时长</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="25"/>
        <source>Moving time</source>
        <translation>移动时长</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="27"/>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="38"/>
        <source>Links</source>
        <translation>链接</translation>
    </message>
</context>
<context>
    <name>WaypointItem</name>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="25"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="26"/>
        <source>Coordinates</source>
        <translation>坐标</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="33"/>
        <source>Elevation</source>
        <translation>海拔</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="36"/>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="40"/>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="44"/>
        <source>Comment</source>
        <translation>评论</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="47"/>
        <source>Symbol</source>
        <translation>符号</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="52"/>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="55"/>
        <source>Phone</source>
        <translation>电话</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="65"/>
        <source>Links</source>
        <translation>链接</translation>
    </message>
</context>
</TS>
